@@ -110,39 +110,41 @@ class Ccp001v1(ClinicalQualityMeasure):
         exposure_response = '150781000119103'
 
         result = False
-        question_responses = self.group_question_responses(self.interview)
-        answers = {r['code']: r['value'] for r in self.interview['responses']}
+        interview = self.interview
+        if interview:
+            question_responses = self.group_question_responses(interview)
+            answers = {r['code']: r['value'] for r in interview['responses']}
 
-        for question, responses in question_responses.items():
-            rationale = ''
-            if question == follow_up_question and follow_up_response in responses:
-                rationale = 'Follow-up requested by care team'
-            elif question == symptom_question:
-                rationale = f'Symptoms exhibited: {", ".join([answers[c] for c in responses])}'
+            for question, responses in question_responses.items():
+                rationale = ''
+                if question == follow_up_question and follow_up_response in responses:
+                    rationale = 'Follow-up requested by care team'
+                elif question == symptom_question:
+                    rationale = f'Symptoms exhibited: {", ".join([answers[c] for c in responses])}'
 
-            if rationale:
-                result = True
-                self.rationales_for_inclusion_in_numerator.append(rationale)
+                if rationale:
+                    result = True
+                    self.rationales_for_inclusion_in_numerator.append(rationale)
 
-        # Recent travel or recent exposure can only be a primary inclusion criteria if the patient is 65+.
-        # If younger, it will be included as context along with other primary inclusion criteria.
-        follow_up = result
-        for question, responses in question_responses.items():
-            rationale = ''
-            if question == travel_question and travel_response in responses:
-                if follow_up:
-                    rationale = 'Recent travel'
-                elif self.patient.age_at(self.anchor_time) >= 65:
-                    rationale = 'Age 65+ with recent travel'
-            elif question == exposure_question and exposure_response in responses:
-                if follow_up:
-                    rationale = 'Recent exposure'
-                elif self.patient.age_at(self.anchor_time) >= 65:
-                    rationale = 'Age 65+ with recent exposure'
+            # Recent travel or recent exposure can only be a primary inclusion criteria if the patient is 65+.
+            # If younger, it will be included as context along with other primary inclusion criteria.
+            follow_up = result
+            for question, responses in question_responses.items():
+                rationale = ''
+                if question == travel_question and travel_response in responses:
+                    if follow_up:
+                        rationale = 'Recent travel'
+                    elif self.patient.age_at(self.anchor_time) >= 65:
+                        rationale = 'Age 65+ with recent travel'
+                elif question == exposure_question and exposure_response in responses:
+                    if follow_up:
+                        rationale = 'Recent exposure'
+                    elif self.patient.age_at(self.anchor_time) >= 65:
+                        rationale = 'Age 65+ with recent exposure'
 
-            if rationale:
-                result = True
-                self.rationales_for_inclusion_in_numerator.append(rationale)
+                if rationale:
+                    result = True
+                    self.rationales_for_inclusion_in_numerator.append(rationale)
 
         return result
 
