@@ -63,7 +63,7 @@ class ClinicalQualityMeasure131v6(ExternallyAwareClinicalQualityMeasure, Diabete
 
     The eye exam must be performed by an ophthalmologist or optometrist.
 
-    More information: https://ecqi.healthit.gov/ecqm/measures/cms131v6
+    More information: https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS131v6.html
     """
 
     class Meta:
@@ -74,7 +74,7 @@ class ClinicalQualityMeasure131v6(ExternallyAwareClinicalQualityMeasure, Diabete
 
         description = ('Patients 18-75 years of age with diabetes who have not had a retinal or '
                        'dilated eye exam by an eye care professional.')
-        information = 'https://ecqi.healthit.gov/ecqm/measures/cms131v6'
+        information = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS131v6.html'
 
         identifiers = ['CMS131v6']
 
@@ -95,8 +95,7 @@ class ClinicalQualityMeasure131v6(ExternallyAwareClinicalQualityMeasure, Diabete
             'American Diabetes Association (ADA). April 2013. Economic Costs of Diabetes in the U.S. in 2012. Diabetes Care. Vol. 36 no. 4 1033-46. http://care.diabetesjournals.org/content/36/4/1033.full',
             'Centers for Disease Control and Prevention (CDC). 2014. National Diabetes Statistics Report. http://www.cdc.gov/diabetes/pdfs/data/2014-report-estimates-of-diabetes-and-its-burden-in-the-united-states.pdf',
             'Centers for Disease Control and Prevention (CDC). 2015. FastStats: Deaths and Mortality. www.cdc.gov/nchs/fastats/deaths.htm.',
-            'Centers for Disease Control and Prevention. 2014. CDC Features. Diabetes Latest. www.cdc.gov/features/diabetesfactsheet/.',
-        ]
+            'Centers for Disease Control and Prevention. 2014. CDC Features. Diabetes Latest. www.cdc.gov/features/diabetesfactsheet/.', ]
 
         compute_on_change_types = [
             ClinicalQualityMeasure.CHANGE_PROTOCOL_OVERRIDE,
