@@ -26,7 +26,7 @@ class ClinicalQualityMeasure122v6Test(SDKBaseTest):
         self.assertEqual(expected, ClinicalQualityMeasure122v6._meta.description)
 
     def test_information(self):
-        expected = 'https://ecqi.healthit.gov/ecqm/measures/cms122v6'
+        expected = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS122v6.html'
         self.assertEqual(expected, ClinicalQualityMeasure122v6._meta.information)
 
     def test_enabled(self):
