@@ -22,7 +22,7 @@ class ClinicalQualityMeasure131v6Test(SDKBaseTest):
         self.assertEqual(expected, ClinicalQualityMeasure131v6._meta.description)
 
     def test_information(self):
-        expected = 'https://ecqi.healthit.gov/ecqm/measures/cms131v6'
+        expected = 'https://ecqi.healthit.gov/sites/default/files/ecqm/measures/CMS131v6.html'
         self.assertEqual(expected, ClinicalQualityMeasure131v6._meta.information)
 
     def test_version(self):
