@@ -19,6 +19,7 @@ from canvas_workflow_kit.patient_recordset import (
     LabReportRecordSet,
     MedicationRecordSet,
     MessageRecordSet,
+    ProcedureRecordSet,
     ProtocolOverrideRecordSet,
     PrescriptionRecordSet,
     ReasonForVisitRecordSet,
@@ -56,6 +57,7 @@ class Patient:
         InterviewRecordSet,
         LabReportRecordSet,
         MedicationRecordSet,
+        ProcedureRecordSet,
         ProtocolOverrideRecordSet,
         PrescriptionRecordSet,
         ReasonForVisitRecordSet,
@@ -104,6 +106,9 @@ class Patient:
         self.messages = MessageRecordSet.new_from(
             data.get(MessageRecordSet.API_UPDATE_FIELD, []))
 
+        self.procedures = ProcedureRecordSet.new_from(
+            data.get(ProcedureRecordSet.API_UPDATE_FIELD, []))
+
         self.protocol_overrides = ProtocolOverrideRecordSet.new_from(
             data.get(ProtocolOverrideRecordSet.API_UPDATE_FIELD, []))
 
