@@ -269,6 +269,7 @@ class TestPatient(SDKBaseTest):
         tested.billing_line_items = BillingLineItemRecordSet([{
             'id': 92,
             'created': '2018-08-05T21:41:21.407046Z',
+            'datetimeOfService': '2018-08-05T21:41:21.407046Z',
             'cpt': '99202',
             'units': 1
         }])
@@ -286,6 +287,7 @@ class TestPatient(SDKBaseTest):
         tested.billing_line_items = BillingLineItemRecordSet([{
             'id': 92,
             'created': '2018-02-05T21:41:21.407046Z',
+            'datetimeOfService': '2018-02-05T21:41:21.407046Z',
             'cpt': '99202',
             'units': 1
         }])
@@ -303,12 +305,12 @@ class TestPatient(SDKBaseTest):
         self.assertEqual(0, result)
 
         tested.billing_line_items = BillingLineItemRecordSet([
-            {'cpt': '99202', 'created': '2018-03-04T21:41:21.407046Z', },
-            {'cpt': '99202', 'created': '2018-03-06T21:41:21.407046Z', },
-            {'cpt': '99212', 'created': '2018-04-05T21:41:21.407046Z', },
-            {'cpt': '99344', 'created': '2018-05-05T21:41:21.407046Z', },
-            {'cpt': '99215', 'created': '2018-06-05T21:41:21.407046Z', },
-            {'cpt': '99215', 'created': '2019-03-06T21:41:21.407046Z', },
+            {'cpt': '99202', 'datetimeOfService': '2018-03-04T21:41:21.407046Z', },
+            {'cpt': '99202', 'datetimeOfService': '2018-03-06T21:41:21.407046Z', },
+            {'cpt': '99212', 'datetimeOfService': '2018-04-05T21:41:21.407046Z', },
+            {'cpt': '99344', 'datetimeOfService': '2018-05-05T21:41:21.407046Z', },
+            {'cpt': '99215', 'datetimeOfService': '2018-06-05T21:41:21.407046Z', },
+            {'cpt': '99215', 'datetimeOfService': '2019-03-06T21:41:21.407046Z', },
         ])  # yapf: disable
         # incorrect ValueSet + billing item --> False
         result = tested.count_visit_within(timeframe, AnnualWellnessVisit)
@@ -324,6 +326,7 @@ class TestPatient(SDKBaseTest):
         tested.billing_line_items = BillingLineItemRecordSet([{
             'id': 92,
             'created': '2018-02-05T21:41:21.407046Z',
+            'datetimeOfService': '2018-02-05T21:41:21.407046Z',
             'cpt': '99202',
             'units': 1
         }])
